@@ -1,14 +1,38 @@
 package Exporter::Handy;
 
 # ABSTRACT: An EXPERIMENTAL subclass of <Exporter::Extensible>, which helps create easy-to-extend modules that export symbols
-our $VERSION = '1.000003';
+our $VERSION = '1.000004';
 
 use utf8;
 use strict;
 use warnings;
 
+use Exporter::Handy::Util qw(xtags);
 use Exporter::Extensible -exporter_setup => 1;
 
+#=== OVERRIDES
+sub exporter_export {
+  my $self = shift;
+  my @args = $self->_exporter_preprocess_export_args(@_);
+  $self->SUPER::exporter_export(@args)
+}
+
+sub _exporter_preprocess_export_args {
+  my $self = shift;
+  my @args;
+  while (@_) {
+    my $arg = shift;
+    if ($arg eq ':') {
+      push @args, xtags( { sig => ':'}, '' => shift )
+    } else {
+      push @args, $arg
+    }
+  }
+  @args
+}
+
+
+# === EXPORT OPTIONS ====
 
 # PRAGMATA
 # Remember: Pragmas effect the current compilation context.
@@ -102,7 +126,7 @@ Exporter::Handy - An EXPERIMENTAL subclass of <Exporter::Extensible>, which help
 
 =head1 VERSION
 
-version 1.000003
+version 1.000004
 
 =head1 SYNOPSIS
 
