@@ -1,7 +1,7 @@
 package Exporter::Handy::Util;
 
 # ABSTRACT: Routines useful when exporting symbols thru Exporter and friends
-our $VERSION = '1.000003';
+our $VERSION = '1.000004';
 
 use utf8;
 use strict;
@@ -58,19 +58,11 @@ sub xtags { # useful for building export tags
 sub expand_xtags {
   local $_;
   my %tags;  %tags = ( %tags, %{; shift } ) while _is_plain_hashref($_[0]);   # tags at start
-  my %opt;   %opt  = ( %opt,  %{; pop   } ) while _is_plain_hashref($_[-1]);  # options at the end.
 
   # Handle special requests given via options
-  my @keys = _flat( delete $opt{key} // (), delete $opt{keys} // () );
-  for (@keys) {
-    if (_is_plain_scalarref($_) and ($$_ =~  /[*]|ALL/i ) ) {
-      # A scalar ref indicates special handling!
-      # If it deferences to '*' (or 'ALL'), it means "ALL KEYS".
-      push @_, values %tags;
-      next
-    }
-    push @_, $tags{$_};
-  }
+  unshift @_,  _flat( delete $tags{-key} // (), delete $tags{-keys} // () );
+  # unshift @_, \'*' unless @_; # no arguments => ALL keys.
+
   @_ = uniq(@_);
 
   my %seen;
@@ -81,6 +73,13 @@ sub expand_xtags {
     next unless defined;
     ref($_) eq 'ARRAY' and do { unshift @_, @$_; next };
 
+    ref($_) eq 'SCALAR' && ($$_ =~  /[*]|ALL/i ) and do {
+      # A scalar ref indicates special handling!
+      # If it deferences to '*' (or 'ALL'), it means "ALL KEYS".
+      unshift @_, values %tags;
+      next
+    };
+
     next if ref($_);
     next if exists $seen{$_} && ( $seen{$_} // 0 );
     $seen{$_} = 1;
@@ -186,7 +185,7 @@ Exporter::Handy::Util - Routines useful when exporting symbols thru Exporter and
 
 =head1 VERSION
 
-version 1.000003
+version 1.000004
 
 =head1 SYNOPSIS
 
